@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-my $VERSION = '0.5.0';
+my $VERSION = '0.5.1';
 
 use strict;
 # use the ToolKit
@@ -18,7 +18,7 @@ my ($fmw, $crw, $spw, $psfile, $viewer, $converter, $number_of_background);
 my ($begin_from_bottom, $x_scale, $y_scale, $scale_x, $scale_y, $shift_x, $shift_y);
 my (@textfield_frame, @circle_text_frame, @textfield_entry, @entry, @text);
 my (@font, @fontsize, @begin_from_left, @eps_file_entry, @eps_filename, @eps_file_label);
-my ($tickmarks, $print_circle_boundaries, $number_of_labels, $which_field);
+my ($tickmarks, $print_circle_boundaries, $number_of_labels, $which_field, $pidsav);
 my ($menu_help, $menu_options, $graphics_file, $radius_inner, $radius_outer, $starting_angle);
 my ($graphics_directory, $Bounding_X, $Bounding_Y, $x_origin, $y_origin, $debug);
 my (@shift_eps_x, @shift_eps_y, @scale_eps_x, @scale_eps_y, @fontfamily, @fontnames);
@@ -130,16 +130,15 @@ $mw -> geometry("+0+0");
 
 # some key-bindings
 # We want to exit the program with Ctrl-q
-$mw -> bind("<Control-q>", [sub {exit}]);
+$mw -> bind("<Control-q>", [sub {&clean_exit}]);
 $mw -> bind("<Control-l>", [sub {&print_label}]);
 $mw -> bind("<Control-p>", [sub {&preview}]);
 $mw -> bind("<Control-s>", [sub {&write_configuration}]);
 
-# Now we want a frame on the top of the window for the menus
+# Now we want a frame at the top of the window for the menus
 my $menu_frame = $mw -> Frame(-relief => 'raised', -bd => 2) -> pack(-side => 'top',
-								  -fill => 'x',
-								  -anchor => 'n',
-								  -expand => '1');
+								  -fill => 'both',
+								  -anchor => 'n');
 
 $menu_frame -> Menubutton(-text => "File",
                           -underline => 0, -tearoff => 0,
@@ -173,7 +172,7 @@ $menu_frame -> Menubutton(-text => "File",
 					  -underline => 0],
 					 "-",
 					 ['command' => "Exit",
-					  -command => sub{exit},
+					  -command => sub{&clean_exit},
 					  -underline => 1]
 				       ]) -> pack(-side => 'left');
 
@@ -251,34 +250,43 @@ $menu_help -> command(-label => "About",
 # Now we create two frames for the text-entry widgets
 #
 
-$circle_frame = $mw -> Frame(-label => "circles",
-			     -borderwidth => 8,
+$circle_frame = $mw -> Frame(-label => "Circles",
+			     -borderwidth => 4,
 			     -relief => 'groove') -> pack(-side => 'top',
-							  -fill => 'x');
+			                                  -expand => 1,
+							  -fill => 'both');
 
-$text_frame = $mw -> Frame(-label => "textfields",
-			   -borderwidth => 8,
+$text_frame = $mw -> Frame(-label => "Textfields",
+			   -borderwidth => 4,
 			   -relief => 'groove') -> pack(-side => 'bottom',
-							-fill => 'x');
+			                                -expand => 1,
+							-fill => 'both');
 
 # First two frames for the circles
 
-$circle_text_frame[0] = $circle_frame -> Frame(-label => "bottom label",
-			                       -borderwidth => 4,
-			                       -relief => 'groove') -> pack(-side => 'left');
-$circle_text_frame[1] = $circle_frame -> Frame(-label => "top label",
-			                       -borderwidth => 4,
-			                       -relief => 'groove') -> pack(-side => 'right');
-
+$circle_text_frame[0] = $circle_frame -> Frame(-label => "Bottom label",
+			                       -borderwidth => 2,
+			                       -relief => 'groove') -> pack(-side => 'left',
+					                                    -fill => 'both',
+			                                                    -expand => 1);
+$circle_text_frame[1] = $circle_frame -> Frame(-label => "Top label",
+			                       -borderwidth => 2,
+			                       -relief => 'groove') -> pack(-side => 'left',
+					                                    -fill => 'both',
+			                                                    -expand => 1);
 
 # Then two for the textfields
 
-$textfield_frame[0] = $text_frame -> Frame(-label => "bottom label",
-			                   -borderwidth => 4,
-			                   -relief => 'groove') -> pack(-side => 'left');
-$textfield_frame[1] = $text_frame -> Frame(-label => "top label",
-			                   -borderwidth => 4,
-			                   -relief => 'groove') -> pack(-side => 'right');
+$textfield_frame[0] = $text_frame -> Frame(-label => "Bottom label",
+			                   -borderwidth => 2,
+			                   -relief => 'groove') -> pack(-side => 'left',
+					                                -fill => 'both',
+			                                                -expand => 1);
+$textfield_frame[1] = $text_frame -> Frame(-label => "Top label",
+			                   -borderwidth => 2,
+			                   -relief => 'groove') -> pack(-side => 'left',
+					                                -fill => 'both',
+			                                                -expand => 1);
 
 
 # Now create the widgets for the text
@@ -322,6 +330,18 @@ update_display();
 
 MainLoop;
 
+clean_exit();
+
+#######################
+
+sub clean_exit {
+
+  if ($pidsav != 0 ) {
+    `kill -USR1 $pidsav`;
+  }
+  exit 0;
+
+}
 #######################
 # Very incomplete :-(
 #
@@ -490,7 +510,8 @@ sub defaults {
   $number_of_background = 9;
 
   # which previewer
-  $viewer = "gv";
+  check_viewer("gv");
+  $pidsav = 0;
 
   # which converter
   $converter = "convert";
@@ -552,6 +573,27 @@ sub defaults {
   }
 }
 
+#######################
+sub check_viewer {
+
+  my $fn = $_[0];
+
+  if (-x $fn) {
+    $viewer = $fn;
+    return;
+  }
+  
+  for my $dir (split /:/, $ENV{PATH}) {
+    my $file = "$dir/$fn";
+    if ( -x $file) {
+      $viewer = $file;
+      last;
+    }
+  }
+
+  return;
+}
+
 ########################
 sub default_attributes {
   # fontsizes
@@ -574,19 +616,19 @@ sub default_text {
 
   # The entries for the circle text
 
-  $text[0][0] = "T-Shirts for";
-  $text[0][1] = "unix friends";
+  $text[0][0] = "CD-Circleprint";
+  $text[0][1] = "";
   $text[0][2] = "";
-  $text[0][3] = "www.unixstuff.de";
+  $text[0][3] = "";
 
   $text[1][0] = "www.debian.org";
   $text[1][1] = "GNU/Linux GNU/Hurd";
-  $text[1][2] = "The FREE distribution";
-  $text[1][3] = "";
+  $text[1][2] = "";
+  $text[1][3] = "The FREE distribution";
 
   # The entries for the straight text
   
-  $text[0][4] = " ";
+  $text[0][4] = "$VERSION";
   $text[0][5] = " ";
   $text[0][6] = " ";
   $text[0][7] = " ";
@@ -721,7 +763,7 @@ sub about_window {
   $text -> insert('end', "cd-circleprint is published under the GNU public license\n");
   $text -> insert('end', "You should have this license in your distribution\n");
   $text -> insert('end', "If you don't, write to the Free Software Foundation, Inc., \n");
-  $text -> insert('end', "59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.\n\n");
+  $text -> insert('end', "51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA.\n\n");
   $text -> tagConfigure('red', -foreground => "#ff0000");
   $text -> insert('end',"May the source be with you", 'red');
 
@@ -810,10 +852,38 @@ my $fdfile = $FSref -> Show;
 ########################
 sub preview {
 
-  # first we want a new label
+  my $pid;
+  
+# first we want a new label
   print_label();
 
-  system "$viewer $psfile";
+# next kill any previous viewer
+  if ($pidsav != 0 ) {
+    `kill -USR1 $pidsav`;
+    $pidsav = 0;
+  }
+
+# check viewer is executable
+
+  if ( -x $viewer) {
+
+# then fork to the viewer
+
+    if ($pid = fork) {
+      $pidsav = $pid;   # we are the parent so save child pid
+      return;
+    }
+    elsif (defined $pid) {
+      exec $viewer, $psfile;
+    }
+  }
+  
+# if we get here then an error occured
+
+my $warn => $mw->messageBox( -title => 'Error',
+                             -message => 'Error attempting to start previewer',
+			     -type => 'OK');
+
   return;
 }
 
@@ -1688,12 +1758,14 @@ sub get_graphics {
 
   $fwshift -> Scale(-label => "Offset X",
 		    -from => -$radius_outer, -to => $radius_outer,
+		    -resolution => "0.1",
 		    -orient => "horizontal",
 		    -command => sub{set_graphics_attributes()},
 		    -variable => \$shift_x) -> pack(-side => "left");
 
   $fwshift -> Scale(-label => "Offset Y",
 		    -from => $radius_outer, -to => -$radius_outer,
+		    -resolution => "0.1",
 		    -orient => "vertical",
 		    -command => sub{set_graphics_attributes()},
 		    -variable => \$shift_y) -> pack(-side => "right");
@@ -1737,8 +1809,9 @@ sub get_previewer {
                              -acceptlabel => 'Ok');
   $pv = $FSref -> Show;
 
-  $viewer = $pv if defined $pv;
-#We should verify that the chosen file is executable !!!!!!!!!!!
+  if (defined $pv) {
+    check_viewer($pv);
+  }
 }
 ########################
 sub get_starting_angle {
@@ -1750,7 +1823,7 @@ sub get_starting_angle {
 
   $starting_angle_window -> Scale(-label => "Angle to middle of text",
 				  -from => -90, -to => 90,
-				  -resolution => "1",
+				  -resolution => "0.5",
 				  -orient => "horizontal", -length => 250,
 				  -variable => \$starting_angle) -> pack(-side => "top");
 
@@ -1806,7 +1879,8 @@ if (! Exists($crw)) {
                         -> pack(-side => 'top');
     $tf -> Scale(-orient => 'horizontal',
 		  -variable => \$radius_inner,
-		  -from => 0, -to => 50,) -> pack(-side => 'left');
+		  -from => 0, -to => 50,
+		  -resolution => "0.5",) -> pack(-side => 'left');
 
     $bf = $crw -> Frame(-label => "Radius of the text-circles [mm]") -> pack(-side => 'bottom');
     # Now the radii for the text circles
@@ -1818,7 +1892,8 @@ if (! Exists($crw)) {
       for ( my $i=0; $i<4 ; $i++) {
 	$lf[$j] -> Scale(-orient => 'horizontal',
 		     -variable => \$circle_radius[$j][$i],
-		     -from => $radius_inner, -to => $radius_outer,) -> pack(-side => 'top');
+		     -from => $radius_inner, -to => $radius_outer,
+		     -resolution => "0.5",) -> pack(-side => 'top');
       }
     }
   }
@@ -1926,7 +2001,7 @@ sub set_positions {
 
     $fw -> Scale(-label => "distance between the circles",
 		 -variable => \$delta,
-		 -resolution => 1,
+		 -resolution => 0.1,
 		 -from => 100, -to => 0 ) -> pack(-side => 'right');
 
     $fw->Entry(-textvariable => \$delta,
